# Signal, Pseudo Voigt IRF

When istrument response function is modeled as pseudo voigt profile, then since, pseudo voigt profile is just linear combination of cauchy and gaussian distribution, experimental signal could be modeled as linear combination of ${Signal}_c$ and ${Signal}_g$.

\begin{equation*}
{Signal}_{pv}(t, \eta, {fwhm}) = \eta {Signal}_c(t, {fwhm}) + (1-\eta) {Signal}_g(t, {fwhm})
\end{equation*}
